"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const Hapi = require("hapi");
const Boom = require("boom");
const api_util_1 = require("@cashfarm/api-util");
const plow_1 = require("@cashfarm/plow");
/**
 * Catch-all controller
 *
 * This controller's route `notFound` will catch any request for
 * routes that are not matched by any existing controller
 *
 * @export
 * @class CatchAll
 * @implements {IController}
 */
let CatchAll = class CatchAll {
    notFound(req, reply) {
        const accept = req.raw.req.headers.accept;
        if (accept && accept.match(/json/)) {
            const err = Boom.notFound('Endpoint not found', { url: req.url });
            err.output.payload.data = err.data;
            return reply(err);
        }
        reply().code(404);
    }
};
tslib_1.__decorate([
    api_util_1.Endpoint('GET', '/{any*}', {
        description: 'Matchs any url to log 404 requests',
        tags: ['api']
    }),
    tslib_1.__metadata("design:type", Function),
    tslib_1.__metadata("design:paramtypes", [Hapi.Request, Function]),
    tslib_1.__metadata("design:returntype", void 0)
], CatchAll.prototype, "notFound", null);
CatchAll = tslib_1.__decorate([
    plow_1.provide('IController')
], CatchAll);
exports.CatchAll = CatchAll;
exports.default = CatchAll;
//# sourceMappingURL=404.js.map