"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
// tslint:disable:no-console
// tslint:disable:no-import-side-effect
const betterErrors_1 = require("./ext/betterErrors");
const config_1 = require("./config");
require("@cashfarm/api-util/lib/hapi/router");
const plow_1 = require("@cashfarm/plow");
const container_config_1 = require("./container.config");
const Glue = require('glue');
const composeOptions = {
    relativeTo: __dirname
};
function createServer(serviceName, override, customContainer) {
    return tslib_1.__awaiter(this, void 0, void 0, function* () {
        return new Promise((resolve, reject) => {
            const options = {
                debug: true,
                enableCors: true,
                port: 3000
            };
            if (typeof override === 'object') {
                Object.assign(options, override);
            }
            const criteria = {
                env: process.env.NODE_ENV || 'development',
                debug: 'on'
            };
            const manifest = config_1.default.get('/', criteria);
            // @todo Find a better way to configure the port
            manifest.connections[0].port = options.port;
            Glue.compose(manifest, composeOptions, (err, server) => {
                if (err) {
                    return reject(err);
                }
                if (customContainer) {
                    container_config_1.setupContainer(customContainer, serviceName, server, options);
                    server.decorate('server', 'getContainer', () => customContainer);
                }
                else {
                    container_config_1.setupContainer(plow_1.container, serviceName, server, options);
                    server.decorate('server', 'getContainer', () => plow_1.container);
                }
                if (options.enableCors) {
                    const addCorsHeaders = require('hapi-cors-headers');
                    server.ext('onPreResponse', addCorsHeaders);
                }
                if (options.debug) {
                    server.settings.debug = { log: ['error', 'uncaught'], request: ['error', 'uncaught'] };
                    server.ext('onPreResponse', betterErrors_1.betterErrors);
                }
                if (typeof override === 'function') {
                    override(server);
                }
                server.on('start', () => {
                    server.getRouter().addControllers(plow_1.container.getAll('IController'));
                });
                resolve(server);
            });
        });
    });
}
exports.createServer = createServer;
//# sourceMappingURL=server.js.map